@@ -3,5 +3,6 @@ OVERSEER_CONFIG = {
     'TWITTER_CONSUMER_SECRET': '5lze2bXfEiZQVndH6F3VlQWlpYvG3ixV69FGLKcums',
     'TWITTER_ACCESS_TOKEN':  '241259795-wVnWHabmoI08hbucKhJF1y2CI4wKvbGyEoF0Ange',
     'TWITTER_ACCESS_SECRET': 'lNkf6CKYPLmh3szcfe3ueQdg076facQMqGKFYzwT2A',
-    'BASE_URL': 'http://status.disqus.com'
+    'BASE_URL': 'http://status.disqus.com',
+	'ALLOW_SUBSCRIPTIONS': True,
 }
\ No newline at end of file
